@@ -172,8 +172,11 @@ class Plotter:
             self.plot(config, *args, **kwargs)
         return
     
-    def plot(self, config, save_as=None, data=None, dpi=None, **kwargs):
+    def plot(self, config, save_as=None, data=None, dpi=None, legend_kwargs={}, **kwargs):
         """ Plot based on the configuration from CSV """
+        if data is None:  # Check explicitly for None
+            data = self.data  # Use self.data if no data is provided
+
         config.update(kwargs)
 
         # Set the y_var as a list if it is a string
@@ -183,18 +186,16 @@ class Plotter:
         # Only keep the columns that are present in the data
         config['x_var'] = config['x_var'] if config['x_var'] in data.columns else ''
         config['y_var'] = [y for y in config['y_var'] if y in data.columns]
-        
+
         # Set the labels if not provided
         if not config.get('y_var_label', None):
             config['y_var_label'] = config['y_var']
+        config['y_var_label'] = [l if l else v for v, l in zip(config['y_var'], config['y_var_label'])]
 
         # Apply the selected style
         self.apply_style(self.style)
         
         #self._set_theme(config.get('theme', 'light'), config.get('palette', 'viridis'))
-
-        if data is None:  # Check explicitly for None
-            data = self.data  # Use self.data if no data is provided
         
         plt.figure(figsize=Plotter._get_figure_size(
             config.get('aspect', 'wide')))
@@ -235,6 +236,9 @@ class Plotter:
         # Try to set date ticks
         self.try_date_ticks(data, config['x_var'], axis=0)
 
+        # Add a legend if requested
+        plt.legend(**legend_kwargs)
+
         # Adjust the padding between and around subplots
         plt.tight_layout()
 
